@@ -1,5 +1,5 @@
 /* 
- * $Id: ftp_session.c,v 1.46 2001/05/27 22:40:39 shane Exp $
+ * $Id: ftp_session.c,v 1.47 2004/03/25 20:46:35 shane Exp $
  */
 
 #include <config.h>
@@ -1637,12 +1637,20 @@ static void do_size(ftp_session_t *f, const ftp_command_t *cmd)
         if (stat(full_path, &stat_buf) != 0) {
             reply(f, 550, "Error getting file status; %s.", strerror(errno));
         } else {
-            /* output the size */
-            if (sizeof(off_t) == 8) {
-                reply(f, 213, "%llu", stat_buf.st_size);
+
+            /* verify that the file is not a directory */
+            if (S_ISDIR(stat_buf.st_mode)) {
+                reply(f, 550, "File is a directory, SIZE command not valid.");
             } else {
-                reply(f, 213, "%lu", stat_buf.st_size);
-            } 
+
+                /* output the size */
+                if (sizeof(off_t) == 8) {
+                    reply(f, 213, "%llu", stat_buf.st_size);
+                } else {
+                    reply(f, 213, "%lu", stat_buf.st_size);
+                }
+            }
+
         }
 
     }
